==> nextcloud-28.0.14.tgz: nextcloud/apps/federatedfilesharing/l10n/es_EC.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "El ID es inválido",
    "Server to server sharing is not enabled on this server" : "Compartir de servidor a servidor no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No fue posible establecer el elemento compartido. ",
    "Couldn't establish a federated share, maybe the password was wrong." : "No fue posible establecer el elemento compartido federado, tal vez la contraseña sea incorrecta. ",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitud de elemento compartido Federado enviada, recibiras una invitación. Verifica tus notificaciones.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No fue posible establecer el elemento compartido, parece que el servidor es obsoleto (Nextcloud <=9).",
    "It is not allowed to send federated group shares from this server." : "No está permitido enviar comparticiones de grupos federados desde este servidor.",
    "Federated shares require read permissions" : "Las comparticiones federadas requieren permisos de lectura",
    "File is already shared with %s" : "El archivo ya ha sido compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "La compartición de %1$s falló, no se pudo encontrar %2$s, tal vez el servidor no está disponible actualmente o utiliza un certificado autofirmado.",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "Federated sharing" : "Elementos compartidos",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received {share} as a remote share from {user}" : "Recibiste {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Federated Cloud Sharing" : "Compartiendo en la Nube Federada",
    "Sharing" : "Compartiendo",
    "Federated file sharing" : "Compartir  elementos",
    "Provide federated file sharing across servers" : "Proporciona compartición de archivos federada entre servidores",
    "Unable to update federated files sharing config" : "No se pudo actualizar la configuración de compartición federada de archivos",
    "Federated Cloud" : "Nube Federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "¡Puedes compartir con cualquier persona que utilice un servidor Nextcloud u otros servidores y servicios compatibles con Open Cloud Mesh (OCM)! Simplemente ingresa su ID de Nube Federada en el diálogo de compartición. Se ve como person@cloud.example.com",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Facebook" : "Facebook",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Agregar a tu sitio web",
    "Share with me via Nextcloud" : "Compartir conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparte conmigo a través de mi ID de Nube Federada de #Nextcloud, consulta {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Cloud ID copied to the clipboard" : "ID de Nube copiado al portapapeles",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Copied!" : "¡Copiado!",
    "Cancel" : "Cancelar",
    "Add remote share" : "Agregar elemento compartido remoto",
    "Remote share" : "Elemento compartido remoto",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea agregar el elemento compartido remoto {name} de {owner}@{remote}?",
    "Remote share password" : "Contraseña del elemento compartido remoto",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "La compartición de %1$s falló, porque este elemento ya está compartido con el usuario %2$s",
    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Ajusta cómo las personas pueden compartir entre servidores. Esto incluye comparticiones entre usuarios en este servidor si están utilizando compartición federada.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permite a los usuarios de este servidor enviar comparticiones a otros servidores (esta opción también permite el acceso WebDAV a comparticiones públicas)",
    "Allow users on this server to receive shares from other servers" : "Permitirle alos usuarios de este servidor recibir elementos compartidos de otros servidores",
    "Allow users on this server to send shares to groups on other servers" : "Permite a los usuarios de este servidor enviar comparticiones a grupos en otros servidores",
    "Allow users on this server to receive group shares from other servers" : "Permite a los usuarios de este servidor recibir comparticiones de grupos de otros servidores",
    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
    "Allow users to publish their data to a global and public address book" : "Permitirle a los usuarios publicar sus datos a una libreta de direcciones global y pública",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Clipboard is not available" : "El portapapeles no está disponible"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.8.tgz: nextcloud/apps/federatedfilesharing/l10n/es_EC.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "El ID es inválido",
    "Server to server sharing is not enabled on this server" : "Compartir de servidor a servidor no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No fue posible establecer el elemento compartido. ",
    "Couldn't establish a federated share, maybe the password was wrong." : "No fue posible establecer el elemento compartido federado, tal vez la contraseña sea incorrecta. ",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitud de elemento compartido Federado enviada, recibiras una invitación. Verifica tus notificaciones.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No fue posible establecer el elemento compartido, parece que el servidor es obsoleto (Nextcloud <=9).",
    "It is not allowed to send federated group shares from this server." : "No está permitido enviar comparticiones de grupos federados desde este servidor.",
    "Federated shares require read permissions" : "Las comparticiones federadas requieren permisos de lectura",
    "File is already shared with %s" : "El archivo ya ha sido compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "La compartición de %1$s falló, no se pudo encontrar %2$s, tal vez el servidor no está disponible actualmente o utiliza un certificado autofirmado.",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "Federated sharing" : "Elementos compartidos",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received {share} as a remote share from {user}" : "Recibiste {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Federated Cloud Sharing" : "Compartiendo en la Nube Federada",
    "Sharing" : "Compartiendo",
    "Federated file sharing" : "Compartir  elementos",
    "Provide federated file sharing across servers" : "Proporciona compartición de archivos federada entre servidores",
    "Unable to update federated files sharing config" : "No se pudo actualizar la configuración de compartición federada de archivos",
    "Federated Cloud" : "Nube Federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "¡Puedes compartir con cualquier persona que utilice un servidor Nextcloud u otros servidores y servicios compatibles con Open Cloud Mesh (OCM)! Simplemente ingresa su ID de Nube Federada en el diálogo de compartición. Se ve como person@cloud.example.com",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Facebook" : "Facebook",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Agregar a tu sitio web",
    "Share with me via Nextcloud" : "Compartir conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparte conmigo a través de mi ID de Nube Federada de #Nextcloud, consulta {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Cloud ID copied to the clipboard" : "ID de Nube copiado al portapapeles",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea agregar el elemento compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Elemento compartido remoto",
    "Remote share password" : "Contraseña del elemento compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Agregar elemento compartido remoto",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "La compartición de %1$s falló, porque este elemento ya está compartido con el usuario %2$s",
    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Ajusta cómo las personas pueden compartir entre servidores. Esto incluye comparticiones entre usuarios en este servidor si están utilizando compartición federada.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permite a los usuarios de este servidor enviar comparticiones a otros servidores (esta opción también permite el acceso WebDAV a comparticiones públicas)",
    "Allow users on this server to receive shares from other servers" : "Permitirle alos usuarios de este servidor recibir elementos compartidos de otros servidores",
    "Allow users on this server to send shares to groups on other servers" : "Permite a los usuarios de este servidor enviar comparticiones a grupos en otros servidores",
    "Allow users on this server to receive group shares from other servers" : "Permite a los usuarios de este servidor recibir comparticiones de grupos de otros servidores",
    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
    "Allow users to publish their data to a global and public address book" : "Permitirle a los usuarios publicar sus datos a una libreta de direcciones global y pública",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Clipboard is not available" : "El portapapeles no está disponible",
    "Copied!" : "¡Copiado!"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
